@@ -1,7 +1,79 @@
+#' tepGraphs: TExPosition plotting function
+#' 
+#' TExPosition plotting function which is an interface to
+#' \code{\link[prettyGraphs]{prettyGraphs}}.
+#' 
+#' tepGraphs is an interface between \code{\link{TExPosition}} and
+#' \code{\link[prettyGraphs]{prettyGraphs}}.
+#' 
+#' @param res results from TExPosition
+#' @param x_axis which component should be on the x axis?
+#' @param y_axis which component should be on the y axis?
+#' @param tepPlotInfo A list (\code{$Plotting.Data}) from \code{tepGraphs} or
+#' \code{TExPosition}.
+#' @param DESIGN A design matrix to apply colors (by pallete selection) to row
+#' items
+#' @param fi.col A matrix of colors for the group items. If NULL, colors will
+#' be selected.
+#' @param fi.pch A matrix of pch values for the group items. If NULL, pch
+#' values are all 21.
+#' @param fii.col A matrix of colors for the row items (observations). If NULL,
+#' colors will be selected.
+#' @param fii.pch A matrix of pch values for the row items (observations). If
+#' NULL, pch values are all 21.
+#' @param fj.col A matrix of colors for the column items. If NULL, colors will
+#' be selected.
+#' @param fj.pch A matrix of pch values for the column items. If NULL, pch
+#' values are all 21.
+#' @param col.offset A numeric offset value. Is passed to
+#' \code{\link[prettyGraphs]{createColorVectorsByDesign}}.
+#' @param constraints Plot constraints as returned from
+#' \code{\link[prettyGraphs]{prettyPlot}}. If NULL, constraints are selected.
+#' @param lv.constraints Plot constraints for latent variables. If NULL,
+#' constraints are selected.
+#' @param xlab x axis label
+#' @param ylab y axis label
+#' @param main main label for the graph window
+#' @param lvPlots a boolean. If TRUE, latent variables (X, Y) are plotted. If
+#' FALSE, latent variables are not plotted.
+#' @param lvAgainst a boolean. If TRUE, latent variables (X, Y) are plotted
+#' against each other. If FALSE, latent variables are plotted like factor
+#' scores.
+#' @param contributionPlots a boolean. If TRUE (default), contribution bar
+#' plots will be created.
+#' @param correlationPlotter a boolean. If TRUE (default), a correlation circle
+#' plot will be created. Applies to PCA family of methods (CA is excluded for
+#' now).
+#' @param showHulls a value between 0 and 1 to make a peeled hull at that
+#' percentage. All values outside of 0-1 will not plot any hulls.
+#' @param graphs a boolean. If TRUE, graphs are created. If FALSE, only data
+#' associated to plotting (e.g., constraints, colors) are returned.
+#' @return The following items are bundled inside of $Plotting.Data:\cr
+#' \item{$fii.col}{the colors that are associated to the individuals (row
+#' items; $fii).} \item{$fii.pch}{the pch values associated to the individuals
+#' (row items; $fii).} \item{$fi.col}{the colors that are associated to the
+#' groups ($fi).} \item{$fi.pch}{the pch values associated to the groups
+#' ($fi).} \item{$fj.col}{the colors that are associated to the column items
+#' ($fj).} \item{$fj.pch}{the pch values associated to the column items ($fj).}
+#' \item{$constraints}{axis constraints for the plots (determines end points of
+#' the plots).}
+#' @author Derek Beaton
+#' @seealso \code{\link[prettyGraphs]{prettyGraphs}}
+#' @keywords multivariate graphs misc
+#' @examples
+#' 
+#' 	#this is for TExPosition's iris data
+#' 	data(ep.iris)
+#' 	bada.iris <- tepBADA(ep.iris$data,DESIGN=ep.iris$design,
+#' 	  make_design_nominal=FALSE,graphs=FALSE)
+#' 	#there are only 2 components, not 3.		
+#' 	bada.iris.plotting.data <- tepGraphs(bada.iris,x_axis=1,y_axis=2)
+#' 
+#' @export tepGraphs
 tepGraphs <-
-function(res,x_axis=1,y_axis=2,tepPlotInfo=NULL,DESIGN=NULL,fi.col=NULL, fi.pch=NULL, fii.col=NULL, fii.pch = NULL, fj.col=NULL, fj.pch = NULL,col.offset=NULL,constraints=NULL,lv.constraints=NULL,xlab=NULL,ylab=NULL,main=NULL,lvPlots=TRUE,lvAgainst=TRUE,contributionPlots=TRUE,correlationPlotter=TRUE,showHulls=1,biplots=FALSE,graphs=TRUE){
+function(res,x_axis=1,y_axis=2,tepPlotInfo=NULL,DESIGN=NULL,fi.col=NULL, fi.pch=NULL, fii.col=NULL, fii.pch = NULL, fj.col=NULL, fj.pch = NULL,col.offset=NULL,constraints=NULL,lv.constraints=NULL,xlab=NULL,ylab=NULL,main=NULL,lvPlots=TRUE,lvAgainst=TRUE,contributionPlots=TRUE,correlationPlotter=TRUE,showHulls=1,graphs=TRUE){
 
-	pca.types <- c('tepBADA','tepPLS','tepGPLS')
+	pca.types <- c('tepBADA','tepPLS')
 	ca.types <- c('tepDICA','tepPLSCA')
 	bary.types <- c('tepBADA','tepDICA')
 	
@@ -200,11 +272,7 @@ function(res,x_axis=1,y_axis=2,tepPlotInfo=NULL,DESIGN=NULL,fi.col=NULL, fi.pch=
 			fi.plot.info <- prettyPlot(res$fi,x_axis=x_axis,y_axis=y_axis,col=fi.col,axes=TRUE,xlab=xlab,ylab=ylab,main=main,constraints=constraints,contributionCircles=TRUE,contributions=res$ci,pch=fi.pch,dev.new=TRUE)
 		}
 		##FOR ALL PLS
-		if(biplots){
-			fj.plot.info <- prettyPlot(res$fj,x_axis=x_axis,y_axis=y_axis,col=fj.col,axes=FALSE,contributionCircles=TRUE,contributions=res$cj,pch=fj.pch,dev.new=FALSE,new.plot=FALSE)
-		}else{
-			fj.plot.info <- prettyPlot(res$fj,x_axis=x_axis,y_axis=y_axis,col=fj.col,axes=TRUE,xlab=xlab,ylab=ylab,main=main,constraints=constraints,pch=fj.pch,contributionCircles=TRUE,contributions=res$cj,dev.new=TRUE)	
-		}
+		fj.plot.info <- prettyPlot(res$fj,x_axis=x_axis,y_axis=y_axis,col=fj.col,axes=TRUE,xlab=xlab,ylab=ylab,main=main,constraints=constraints,pch=fj.pch,contributionCircles=TRUE,contributions=res$cj,dev.new=TRUE)	
 		
 		##For all PLS, but looks weird for barycentric methods. 
 		###PLOT LVs
@@ -236,5 +304,6 @@ function(res,x_axis=1,y_axis=2,tepPlotInfo=NULL,DESIGN=NULL,fi.col=NULL, fi.pch=
 	
 	tepPlotInfo <- list(fii.col=fii.col, fii.pch=fii.pch,fi.col=fi.col, fi.pch=fi.pch,fj.col=fj.col,fj.pch=fj.pch,constraints=constraints,lv.constraints=lv.constraints)
 	class(tepPlotInfo) <- c("tepGraphs", "list")
-	return(tepPlotInfo)	
-}
\ No newline at end of file
+	#return(tepPlotInfo)
+	invisible(tepPlotInfo)	
+}
